import { Provider, Repository, Branch, Webhook, ProviderName, User, PullRequest, RepositoryPermission, PermissionScopes, GitAuth, RefreshTokenHandler } from './types';
import { RetryConfigMap } from '../helpers/request-retry';
export declare const avatarSize = 64;
export default class BitbucketServer implements Provider {
    private baseUrl;
    private authenticationHeader;
    private timeout;
    private agent?;
    private auth;
    private refreshTokenHandler?;
    private retryConfig?;
    constructor(opts: {
        password: string;
        username?: string;
        refreshToken?: string;
        type: 'basic' | 'oauth2' | 'PAT';
        apiURL?: string;
        apiUrl?: string;
        timeout?: number;
        insecure?: boolean;
        refreshTokenHandler?: RefreshTokenHandler;
        retryConfig?: RetryConfigMap;
    });
    createRepository(opt: {
        owner: string;
        repo: string;
        autoInit?: boolean;
        private?: boolean;
    }): Promise<Repository>;
    private shouldRefreshToken;
    private updateAuth;
    private performAPICall;
    private paginateForResult;
    private getProjectKey;
    private getProjectByKey;
    getName(): ProviderName;
    fetchRawFile(opts: {
        owner: string;
        repo: string;
        ref: string;
        path: string;
    }): Promise<string>;
    getBranch(opts: {
        owner: string;
        repo: string;
        branch: string;
    }): Promise<Branch>;
    getRepository(opts: {
        owner: string;
        repo: string;
    }): Promise<Repository>;
    listBranches(opt: {
        owner: string;
        repo: string;
        limit?: number;
        page?: number;
    }): Promise<Branch[]>;
    listRepositoriesForOwner(opt: {
        owner: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
        page?: number;
    }): Promise<Repository[]>;
    createRepositoryWebhook(opt: {
        owner: string;
        repo: string;
        endpoint: string;
        secret: string;
    }): Promise<Webhook>;
    listWebhooks(opt: {
        owner: string;
        repo: string;
        limit?: number;
        page?: number;
    }): Promise<Webhook[]>;
    deleteRepositoryWebhook(opt: {
        owner: string;
        repo: string;
        hookId: number;
    }): Promise<void>;
    listRepositoriesWithAffiliation(opt: {
        affiliation: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
        page?: number;
    }): Promise<Repository[]>;
    listOrganizations(opt: {
        limit?: number;
        page?: number;
    }): Promise<string[]>;
    getRepositoryPermissions(opt: {
        owner: string;
        repo: string;
    }): Promise<RepositoryPermission>;
    listRepositoriesForOrganization(opt: {
        organization: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
        page?: number;
    }): Promise<Repository[]>;
    createCommitStatus(opt: {
        owner: string;
        repo: string;
        sha: string;
        targetUrl: string;
        state: string;
        description: string;
        context: string;
    }): Promise<void>;
    getUser(opt?: {
        username?: string;
    }): Promise<User>;
    getUserByEmail(email: string): Promise<User>;
    getPullRequestFiles(opt: {
        owner: string;
        repo: string;
        pullNumber: number;
    }): Promise<string[]>;
    getPullRequest(opt: {
        owner: string;
        repo: string;
        pullNumber: number;
    }): Promise<PullRequest>;
    assertApiScopes(opt: {
        scopes: PermissionScopes[];
        repoUrl?: string;
    }): Promise<void>;
    assertReadScope(): Promise<void>;
    assertWriteScope(repoUrl: string): Promise<void>;
    assertAdminScope(): Promise<void>;
    toOwnerRepo(fullRepoName: string): [string, string];
    getAuth(): GitAuth;
    isTokenMutable(): boolean;
    requiresRepoToCheckTokenScopes(): boolean;
}
//# sourceMappingURL=bitbucket-server.d.ts.map